metadata

package
v0.94.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 13, 2025 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const Name = "imagecheck"

Name is the name of the application.

Variables

var (
	// Version is the version of the application set during build with -ldflags.
	Version string

	// Hostname is the hostname of the machine running the application.
	Hostname string

	// Username is the username of the user running the application.
	Username string

	// GitRepoName is the name of the git repository.
	GitRepoName string
)

"constants" with non-trivial initialization.

Functions

This section is empty.

Types

type BuildInfo

type BuildInfo struct {
	Commit    string `json:"commit"`
	Dirty     bool   `json:"dirty"`
	Timestamp string `json:"timestamp"`
}

BuildInfo represents the build information for the application.

var Build BuildInfo

Build represents the build information for the application.

Jump to